/* This file has been prepared for Doxygen automatic documentation generation.*/
/*! \file *********************************************************************
 *
 * \brief
 *      Headerfile for ADC.c
 *
 *      Contains definitions for ADC setup, and minimum supply voltage.
 *
 * \par Application note:
 *      AVR458: Charging Li-Ion Batteries with BC100
 *
 * \par Documentation:
 *      For comprehensive code documentation, supported compilers, compiler
 *      settings and supported devices see readme.html
 *
 * \author
 *      Atmel Corporation: http://www.atmel.com \n
 *      Support email: avr@atmel.com \n
 *      Original author: \n
 *
 * $Name$
 * $Revision: 2261 $
 * $RCSfile$
 * $URL: http://svn.norway.atmel.com/AppsAVR8/avr458_Charging_Li-Ion_Batteries_with_BC100/tag/20070904_release_1.0/code/IAR/ADC.h $
 * $Date: 2007-08-10 09:28:35 +0200 (fr, 10 aug 2007) $\n
 ******************************************************************************/

#ifndef ADC_H
#define ADC_H

#include <avr/eeprom.h>

//******************************************************************************
// ADC setup
//******************************************************************************
// 8MHz / (25x128) = 2500 samples/s/ch
#define ADC_PRESCALER     0x07
/*!< \brief Prescaling of ADC clock.
 *
 * The ADC will run at 8 MHz (system clock) divided by 128
 * (prescaler), and every sample will takes approximately 25 ticks:
 * Sample rate = 8 MHz / (128 * 25 cycles/sample) = 2.5 k samples/sec
 */


//******************************************************************************
// Minimum supply voltage
//******************************************************************************
//! Minimum supply voltage (at TP101 = VIN+), in mV.
#define VIN_MIN               4400


//******************************************************************************
// Global variables
//******************************************************************************
extern unsigned char EEMEM VBAT_RANGE;
extern volatile ADC_Status_t ADCS;


//******************************************************************************
// Function prototypes
//******************************************************************************
unsigned int ScaleU(unsigned char setting, unsigned int data);
unsigned int ScaleI(unsigned char setting, unsigned int data);
void ADC_Wait(void);
void ADC_Init(void);

#endif // ADC_H

