/* This file has been prepared for Doxygen automatic documentation generation.*/
/*! \file *********************************************************************
 *
 * \brief
 *      Headerfile for USI.c
 *
 *      Contains definitions of which I/O-register and pins to use,
 *      communication states, and a declaration of the SPI status struct.
 *
 * \par Application note:
 *      AVR458: Charging Li-Ion Batteries with BC100
 *
 * \par Documentation:
 *      For comprehensive code documentation, supported compilers, compiler
 *      settings and supported devices see readme.html
 *
 * \author
 *      Atmel Corporation: http://www.atmel.com \n
 *      Support email: avr@atmel.com \n
 *
 * $Name$
 * $Revision: 2261 $
 * $RCSfile$
 * $URL: http://svn.norway.atmel.com/AppsAVR8/avr458_Charging_Li-Ion_Batteries_with_BC100/tag/20070904_release_1.0/code/IAR/USI.h $
 * $Date: 2007-08-10 09:28:35 +0200 (fr, 10 aug 2007) $\n
 ******************************************************************************/

#ifndef USI_H
#define USI_H

//******************************************************************************
// USI port and pin definitions
//******************************************************************************
#define USI_OUT_REG       PORTB   //!< USI port output register.
#define USI_IN_REG        PINB    //!< USI port input register.
#define USI_DIR_REG       DDRB    //!< USI port direction register.
#define USI_CLOCK_PIN     PB2     //!< USI clock I/O pin.
#define USI_DATAIN_PIN    PB0     //!< USI data input pin.
#define USI_DATAOUT_PIN   PB1     //!< USI data output pin.


//******************************************************************************
// USI/SPI states
//******************************************************************************
enum {
	ST_CMD = 1,  //!< USI/SPI command state.
	ST_ADDR,     //!< USI/SPI address state.
	ST_DATA      //!< USI/SPI data state.
};


//******************************************************************************
// Struct declarations
//******************************************************************************
//! \brief Holds SPI status and data
struct SPI_Status_struct
{
	unsigned char Data           : 8;  //!< The last received byte.
	unsigned char Address        : 8;  //!< Specifies variable to read/write.
	unsigned char Count          : 6;  //!< The number of bytes to read/write.
	unsigned char State          : 2;  //!< \brief Communication state.
	//!< \note The states are enumerated in USI.h.
		
	
	//! Master wants to read or write? (TRUE/FALSE)
	unsigned char Read           : 1;
	
	//! Read/write from/to EEPROM? (TRUE/FALSE)
	unsigned char EEPROM         : 1;
	
	//! Used by SPI_Put() to determine if last byte was transferred.(TRUE/FALSE)
	unsigned char XferComplete   : 1;
	
	//! Set if SPI_Put() is called before last byte was transferred.(TRUE/FALSE)
	unsigned char WriteCollision : 1; 
};
typedef struct SPI_Status_struct SPI_Status_t; //!< For convenience.


//******************************************************************************
// Function prototypes
//******************************************************************************
void SPI_Init(unsigned char spi_mode);
unsigned char SPI_Put(unsigned char val);
unsigned char SPI_Get(void);
void SPI_Wait(void);

#endif // USI_H
